<?php

namespace Drupal\webex_client;

use Drupal\webex_client\Entity\Webex;

/**
 * This class provides helper methods for managing Webex entities.
 */
class WebexHelper {

  /**
   * Retrieves the default Webex entity configuration.
   *
   * @return \Drupal\webex_client\Entity\Webex|null
   *   Returns the default Webex entity if found, otherwise NULL.
   */
  public static function defaultConfig(): ?Webex {
    $wIds = \Drupal::entityTypeManager()
      ->getStorage('webex')
      ->getQuery()
      ->accessCheck()
      ->condition('default', 1)
      ->execute();
    if ($wIds) {
      return Webex::load(reset($wIds));
    }
    return NULL;
  }

  /**
   * Returns the access token for the default Webex entity.
   *
   * @return string
   *   The access token for the default Webex entity.
   */
  public function accessToken(): string {
    if ($webex = self::defaultConfig()) {
      return $webex->getTokenType() . " " . $webex->getAccessToken();
    }
    return "";
  }

}
