<?php

declare(strict_types=1);

namespace Drupal\webex_client;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides an interface defining a webex entity type.
 */
interface WebexInterface extends ConfigEntityInterface {

  /**
   * Sets the client ID for the Webex entity.
   *
   * @param string $client_id
   *   The client ID to set.
   */
  public function setClientId(string $client_id);

  /**
   * Gets the client ID for the Webex entity.
   *
   * @return string
   *   The client ID.
   */
  public function getClientId();

  /**
   * Sets the client secret for the Webex entity.
   *
   * @param string $client_secret
   *   The client secret to set.
   */
  public function setClientSecret(string $client_secret);

  /**
   * Gets the client secret for the Webex entity.
   *
   * @return string
   *   The client secret.
   */
  public function getClientSecret();

  /**
   * Sets the scope for the Webex entity.
   *
   * @param string $scope
   *   The scope to set.
   */
  public function setScope(string $scope);

  /**
   * Gets the scope for the Webex entity.
   *
   * @return string
   *   The scope.
   */
  public function getScope();

  /**
   * Sets the authorization code for the Webex entity.
   *
   * @param string $code
   *   The authorization code to set.
   */
  public function setCode(string $code);

  /**
   * Gets the authorization code for the Webex entity.
   *
   * @return string
   *   The authorization code.
   */
  public function getCode();

  /**
   * Sets the access token for the Webex entity.
   *
   * @param string $access_token
   *   The access token to set.
   */
  public function setAccessToken(string $access_token);

  /**
   * Gets the access token for the Webex entity.
   *
   * @return string
   *   The access token.
   */
  public function getAccessToken();

  /**
   * Sets the refresh token for the Webex entity.
   *
   * @param string $refresh_token
   *   The refresh token to set.
   */
  public function setRefreshToken(string $refresh_token);

  /**
   * Gets the refresh token for the Webex entity.
   *
   * @return string
   *   The refresh token.
   */
  public function getRefreshToken();

  /**
   * Sets the expiration time for the access token.
   *
   * @param int $expires_in
   *   The expiration time in seconds.
   */
  public function setExpiresIn(int $expires_in = 0);

  /**
   * Gets the expiration time for the access token.
   *
   * @return int
   *   The expiration time in seconds.
   */
  public function getExpiresIn();

  /**
   * Sets the expiration time for the refresh token.
   *
   * @param int $value
   *   The expiration time in seconds.
   */
  public function setRefreshTokenExpiresIn(int $value = 0);

  /**
   * Gets the expiration time for the refresh token.
   *
   * @return int
   *   The expiration time in seconds.
   */
  public function getRefreshTokenExpiresIn();

  /**
   * Sets the token type for the Webex entity.
   *
   * @param string $token_type
   *   The token type to set.
   */
  public function setTokenType(string $token_type);

  /**
   * Gets the token type for the Webex entity.
   *
   * @return string
   *   The token type.
   */
  public function getTokenType();

  /**
   * Sets the default status for the Webex entity.
   *
   * @param bool $default
   *   Whether this entity is the default.
   */
  public function setDefault(bool $default = FALSE);

  /**
   * Checks if this entity is the default.
   *
   * @return bool
   *   TRUE if this entity is the default, FALSE otherwise.
   */
  public function isDefault();

}
